==> rck_python_sdk-1.0.0.tar.gz: rck_python_sdk-1.0.0/setup.py <==
"""
RCK Python SDK 安装配置
"""

from setuptools import setup, find_packages
import os

# 读取README文件
def read_readme():
    readme_path = os.path.join(os.path.dirname(__file__), 'README.md')
    if os.path.exists(readme_path):
        with open(readme_path, 'r', encoding='utf-8') as f:
            return f.read()
    return "RCK Python SDK - 优雅的RCK API客户端"

# 读取requirements
def read_requirements():
    req_path = os.path.join(os.path.dirname(__file__), 'requirements.txt')
    if os.path.exists(req_path):
        with open(req_path, 'r', encoding='utf-8') as f:
            return [line.strip() for line in f if line.strip() and not line.startswith('#')]
    return ['requests>=2.25.0']

setup(
    name="rck-python-sdk",
    version="1.0.0",
    author="RCK Team",
    author_email="support@rck.ai",
    description="优雅的RCK (Relational Calculate Kernel) Python SDK",
    long_description=read_readme(),
    long_description_content_type="text/markdown",
    url="https://github.com/rck/rck-python-sdk",
    packages=find_packages(),
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Topic :: Scientific/Engineering :: Artificial Intelligence",
        "Topic :: Text Processing :: Linguistic",
        "Topic :: Multimedia :: Graphics",
    ],
    python_requires=">=3.7",
    install_requires=read_requirements(),
    extras_require={
        "dev": [
            "pytest>=6.0",
            "pytest-cov>=2.0",
            "black>=21.0",
            "flake8>=3.8",
            "mypy>=0.800",
        ],
        "docs": [
            "sphinx>=4.0",
            "sphinx-rtd-theme>=0.5",
        ],
    },
    keywords="rck, ai, text-analysis, image-generation, api-client",
    project_urls={
        "Bug Reports": "https://github.com/rck/rck-python-sdk/issues",
        "Source": "https://github.com/rck/rck-python-sdk",
        "Documentation": "https://rck-python-sdk.readthedocs.io/",
    },
)

==> rck_python_sdk-1.0.1.tar.gz: rck_python_sdk-1.0.1/setup.py <==
"""
RCK Python SDK installation configuration
"""

from setuptools import setup, find_packages
import os

# Read README file
def read_readme():
    readme_path = os.path.join(os.path.dirname(__file__), 'README.md')
    if os.path.exists(readme_path):
        with open(readme_path, 'r', encoding='utf-8') as f:
            return f.read()
    return "RCK Python SDK - Elegant RCK API client"

# Read requirements
def read_requirements():
    req_path = os.path.join(os.path.dirname(__file__), 'requirements.txt')
    if os.path.exists(req_path):
        with open(req_path, 'r', encoding='utf-8') as f:
            return [line.strip() for line in f if line.strip() and not line.startswith('#')]
    return ['requests>=2.25.0']

setup(
    name="rck-python-sdk",
    version="1.0.1",
    author="RCK Team",
    author_email="support@rck.ai",
    description="Elegant RCK (Relational Calculate Kernel) Python SDK",
    long_description=read_readme(),
    long_description_content_type="text/markdown",
    url="https://github.com/rck/rck-python-sdk",
    packages=find_packages(),
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Topic :: Scientific/Engineering :: Artificial Intelligence",
        "Topic :: Text Processing :: Linguistic",
        "Topic :: Multimedia :: Graphics",
    ],
    python_requires=">=3.7",
    install_requires=read_requirements(),
    extras_require={
        "dev": [
            "pytest>=6.0",
            "pytest-cov>=2.0",
            "black>=21.0",
            "flake8>=3.8",
            "mypy>=0.800",
        ],
        "docs": [
            "sphinx>=4.0",
            "sphinx-rtd-theme>=0.5",
        ],
    },
    keywords="rck, ai, text-analysis, image-generation, api-client",
    project_urls={
        "Bug Reports": "https://github.com/rck/rck-python-sdk/issues",
        "Source": "https://github.com/rck/rck-python-sdk",
        "Documentation": "https://rck-python-sdk.readthedocs.io/",
    },
)
